import {
  api,
  downloadFile,
  createApiUrl
} from '~/utils/axios';


/**
 * 下载关键词模板
 * @param {Object} data
 * @return {Promise} api
 */
export function downloadTemplate(data) {
  downloadFile(createApiUrl('Product.Key/downloadTemplate'), data);
}

/**
 * 导入关键词
 * @param {Object} data
 * @return {Promise} api
 */
export const importExcel = createApiUrl('Product.Key/importExcel');

/**
 * 导出关键词
 * @param {Object} data
 * @return {Promise} api
 */
export function exportExcel(data) {
  downloadFile(createApiUrl('Product.Key/exportExcel'), data);
}








/**
 * 获取关键词列表
 * @param {Object} data
 * @return {Promise} api
 */
export function getKeyList(data) {
  return api.post('Product.Key/getKeyList', data);
}

/**
 * 删除关键词
 * @param {Object} data
 * @return {Promise} api
 */
export function deleteKey(data) {
  return api.post('Product.Key/deleteKey', data, {
    isTransformResponse: true,
    isShowSuccessMessage: true,
    errorMessageText: '删除失败'
  });
}

/**
 * 添加关键词
 * @param {Object} data
 * @return {Promise} api
 */
export function addKey(data) {
  return api.post('Product.Key/addKey', data, {
    isTransformResponse: true,
    isShowSuccessMessage: true,
    errorMessageText: '添加失败'
  });
}
/**
 * 编辑关键词
 * @param {Object} data
 * @return {Promise} api
 */
export function editKey(data) {
  return api.post('Product.Key/editKey', data, {
    isTransformResponse: true,
    isShowSuccessMessage: true,
    errorMessageText: '编辑失败'
  });
}