import {
  api,
  downloadFile,
  createApiUrl
} from '~/utils/axios';


/**
 * 导出产品
 * @param {Object} data
 * @return {Promise} api
 */
export function exportExcel(data) {
  downloadFile(createApiUrl('Product.Product/exportExcel'), data);
}

/**
 * 下载产品模板
 * @param {Object} data
 * @return {Promise} api
 */
export function downloadTemplate(data) {
  downloadFile(createApiUrl('Product.Product/downloadTemplate'), data);
}

/**
 * 导入产品
 * @param {Object} data
 * @return {Promise} api
 */
export const importExcel = createApiUrl('Product.Product/importExcel');

/**
 * 获取产品列表
 * @param {Object} data
 * @return {Promise} api
 */
export function getProductList(data) {
  return api.post('Product.Product/getProductList', data);
}

/**
 * 删除产品
 * @param {Object} data
 * @return {Promise} api
 */
export function deleteProduct(data) {
  return api.post('Product.Product/deleteProduct', data, {
    isTransformResponse: true,
    isShowSuccessMessage: true,
    errorMessageText: '删除失败'
  });
}

/**
 * 添加产品
 * @param {Object} data
 * @return {Promise} api
 */
export function addProduct(data) {
  return api.post('Product.Product/addProduct', data, {
    isTransformResponse: true,
    isShowSuccessMessage: true,
    errorMessageText: '添加失败'
  });
}
/**
 * 编辑产品
 * @param {Object} data
 * @return {Promise} api
 */
export function editProduct(data) {
  return api.post('Product.Product/editProduct', data, {
    isTransformResponse: true,
    isShowSuccessMessage: true,
    errorMessageText: '编辑失败'
  });
}