import { api, downloadFile, createApiUrl } from '~/utils/axios';


/**
* 导出学生
* @param {Object} data
* @return {Promise} api
*/
export function exportExcel(data) {
  downloadFile(createApiUrl('School.Student/exportExcel'), data);
}

/**
 * 下载学生模板
 * @param {Object} data
 * @return {Promise} api
 */
export function downloadTemplate(data) {
  downloadFile(createApiUrl('School.Student/downloadTemplate'), data);
}

/**
 * 导入学生
 * @param {Object} data
 * @return {Promise} api
 */
export const importExcel = createApiUrl('School.Student/importExcel');

/**
 * 获取字典值
 * @param {Object} data
 * @return {Promise} api
 */
export function getDictionary(data) {
  return api.post('Dictionary.Dictionary/getDictionary', data, {
  });
}


/**
 * 获取学生列表
 * @param {Object} data
 * @return {Promise} api
 */
export function getStudentList(data) {
  return api.post('School.Student/getStudentList', data);
}

/**
 * 删除学生
 * @param {Object} data
 * @return {Promise} api
 */
export function deleteStudent(data) {
  return api.post('School.Student/deleteStudent', data, {
    isTransformResponse: true,
    isShowSuccessMessage: true,
    errorMessageText: '删除失败'
  });
}

/**
 * 添加学生
 * @param {Object} data
 * @return {Promise} api
 */
export function addStudent(data) {
  return api.post('School.Student/addStudent', data, {
    isTransformResponse: true,
    isShowSuccessMessage: true,
    errorMessageText: '添加失败'
  });
}
/**
 * 编辑学生
 * @param {Object} data
 * @return {Promise} api
 */
export function editStudent(data) {
  return api.post('School.Student/editStudent', data, {
    isTransformResponse: true,
    isShowSuccessMessage: true,
    errorMessageText: '编辑失败'
  });
}


/**
 * 获取点击后的产品列表
 * @param {Object} data
 * @return {Promise} api
 */
export function getClickProduct(data) {
  return api.post('School.Student/getClickProduct', data, {
  });
}

/**
 * 获取点击后的产品零件列表
 * @param {Object} data
 * @return {Promise} api
 */
export function getClickProductParts(data) {
  return api.post('School.Student/getClickProductParts', data, {
  });
}

/**
 * 获取侧边产品树形
 * @param {Object} data
 * @return {Promise} api
 */
 export function getProductTree(data) {
  return api.post('School.Student/getProductTree', data, {
  });
}

/**
 * 查找未绑定用户列表
 * @param {Object} data
 * @return {Promise} api
 */
 export function notBindUserList(data) {
  return api.post('School.Student/notBindUserList', data, {
  });
}

/**
 * 审核学生
 * @param {Object} data
 * @return {Promise} api
 */
export function auditStudent(data) {
  return api.post('School.Student/auditStudent', data, {
  });
}