import {
  api,
  downloadFile,
  createApiUrl
} from '~/utils/axios';


/**
 * 下载作品模板
 * @param {Object} data
 * @return {Promise} api
 */
export function downloadTemplate(data) {
  downloadFile(createApiUrl('Works.Works/downloadTemplate'), data);
}

/**
 * 导入作品
 * @param {Object} data
 * @return {Promise} api
 */
export const importExcel = createApiUrl('Works.Works/importExcel');

/**
 * 导出作品
 * @param {Object} data
 * @return {Promise} api
 */
export function exportExcel(data) {
  downloadFile(createApiUrl('Works.Works/exportExcel'), data);
}

/**
 * 获取作品列表
 * @param {Object} data
 * @return {Promise} api
 */
export function getWorksList(data) {
  return api.post('Works.Works/getWorksList', data);
}

/**
 * 删除作品
 * @param {Object} data
 * @return {Promise} api
 */
export function deleteWorks(data) {
  return api.post('Works.Works/deleteWorks', data, {
    isTransformResponse: true,
    isShowSuccessMessage: true,
    errorMessageText: '删除失败'
  });
}

/**
 * 添加作品
 * @param {Object} data
 * @return {Promise} api
 */
export function addWorks(data) {
  return api.post('Works.Works/addWorks', data, {
    isTransformResponse: true,
    isShowSuccessMessage: true,
    errorMessageText: '添加失败'
  });
}
/**
 * 编辑作品
 * @param {Object} data
 * @return {Promise} api
 */
export function editWorks(data) {
  return api.post('Works.Works/editWorks', data, {
    isTransformResponse: true,
    isShowSuccessMessage: true,
    errorMessageText: '编辑失败'
  });
}