import {
  api,
  downloadFile,
  createApiUrl
} from '~/utils/axios';


/**
 * 导出作品类型
 * @param {Object} data
 * @return {Promise} api
 */
export function exportExcel(data) {
  downloadFile(createApiUrl('Works.WorksType/exportExcel'), data);
}

/**
 * 下载作品类型模板
 * @param {Object} data
 * @return {Promise} api
 */
export function downloadTemplate(data) {
  downloadFile(createApiUrl('Works.WorksType/downloadTemplate'), data);
}

/**
 * 导入作品类型
 * @param {Object} data
 * @return {Promise} api
 */
export const importExcel = createApiUrl('Works.WorksType/importExcel');

/**
 * 获取作品类型列表
 * @param {Object} data
 * @return {Promise} api
 */
export function getWorksTypeList(data) {
  return api.post('Works.WorksType/getWorksTypeList', data);
}

/**
 * 删除作品类型
 * @param {Object} data
 * @return {Promise} api
 */
export function deleteWorksType(data) {
  return api.post('Works.WorksType/deleteWorksType', data, {
    isTransformResponse: true,
    isShowSuccessMessage: true,
    errorMessageText: '删除失败'
  });
}

/**
 * 添加作品类型
 * @param {Object} data
 * @return {Promise} api
 */
export function addWorksType(data) {
  return api.post('Works.WorksType/addWorksType', data, {
    // isTransformResponse: true,
    // isShowSuccessMessage: true,
    errorMessageText: '添加失败'
  });
}
/**
 * 编辑作品类型
 * @param {Object} data
 * @return {Promise} api
 */
export function editWorksType(data) {
  return api.post('Works.WorksType/editWorksType', data, {
    // isTransformResponse: true,
    // isShowSuccessMessage: true,
    errorMessageText: '编辑失败'
  });
}